@@ -10,10 +10,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import io
+import json
 import os
-import six
+import shutil
 import sys
 import tempfile
+from unittest import mock
 
 from testtools import matchers
 
@@ -24,7 +27,6 @@ from muranoclient.tests.unit.osc.v1 import fakes
 from muranoclient.tests.unit import test_utils
 from muranoclient.v1 import packages
 
-import mock
 from osc_lib import exceptions as exc
 from osc_lib import utils
 import requests_mock
@@ -100,7 +102,7 @@ class TestCreatePackage(TestPackage):
             parsed_args = self.check_parser(self.cmd, arglist, [])
             orig = sys.stdout
             try:
-                sys.stdout = six.StringIO()
+                sys.stdout = io.StringIO()
                 self.cmd.take_action(parsed_args)
             finally:
                 stdout = sys.stdout.getvalue()
@@ -121,7 +123,7 @@ class TestCreatePackage(TestPackage):
             parsed_args = self.check_parser(self.cmd, arglist, [])
             orig = sys.stdout
             try:
-                sys.stdout = six.StringIO()
+                sys.stdout = io.StringIO()
                 self.cmd.take_action(parsed_args)
             finally:
                 stdout = sys.stdout.getvalue()
@@ -279,7 +281,7 @@ class TestPackageImport(TestPackage):
 
             return f.name
 
-    @mock.patch('six.moves.input')
+    @mock.patch('builtins.input')
     @mock.patch('muranoclient.common.utils.Package.from_file')
     def test_package_import_conflict_skip(self, from_file, raw_input_mock):
 
@@ -294,7 +296,7 @@ class TestPackageImport(TestPackage):
             'is_public': False,
         }, {name: mock.ANY},)
 
-    @mock.patch('six.moves.input')
+    @mock.patch('builtins.input')
     @mock.patch('muranoclient.common.utils.Package.from_file')
     def test_package_import_conflict_skip_ea(self, from_file, raw_input_mock):
 
@@ -311,7 +313,7 @@ class TestPackageImport(TestPackage):
         }, {name: mock.ANY},)
         self.assertFalse(raw_input_mock.called)
 
-    @mock.patch('six.moves.input')
+    @mock.patch('builtins.input')
     @mock.patch('muranoclient.common.utils.Package.from_file')
     def test_package_import_conflict_abort(self, from_file, raw_input_mock):
 
@@ -326,7 +328,7 @@ class TestPackageImport(TestPackage):
             'is_public': False,
         }, mock.ANY,)
 
-    @mock.patch('six.moves.input')
+    @mock.patch('builtins.input')
     @mock.patch('muranoclient.common.utils.Package.from_file')
     def test_package_import_conflict_abort_ea(self,
                                               from_file, raw_input_mock):
@@ -344,7 +346,7 @@ class TestPackageImport(TestPackage):
         }, mock.ANY,)
         self.assertFalse(raw_input_mock.called)
 
-    @mock.patch('six.moves.input')
+    @mock.patch('builtins.input')
     @mock.patch('muranoclient.common.utils.Package.from_file')
     def test_package_import_conflict_update(self, from_file, raw_input_mock):
 
@@ -365,7 +367,7 @@ class TestPackageImport(TestPackage):
             ], any_order=True,
         )
 
-    @mock.patch('six.moves.input')
+    @mock.patch('builtins.input')
     @mock.patch('muranoclient.common.utils.Package.from_file')
     def test_package_import_conflict_update_ea(self,
                                                from_file, raw_input_mock):
@@ -548,3 +550,232 @@ class TestPackageImport(TestPackage):
                 mock.call({'is_public': False}, {'second_app': mock.ANY}),
             ], any_order=True,
         )
+
+
+class TestBundleImport(TestPackage):
+    def setUp(self):
+        super(TestBundleImport, self).setUp()
+
+        # Command to test
+        self.cmd = osc_pkg.ImportBundle(self.app, None)
+
+    @requests_mock.mock()
+    def test_import_bundle_by_name(self, m):
+        """Asserts bundle import calls packages create once for each pkg."""
+        pkg1 = make_pkg({'FullName': 'first_app'})
+        pkg2 = make_pkg({'FullName': 'second_app'})
+
+        murano_repo_url = "http://127.0.0.1"
+
+        m.get(murano_repo_url + '/apps/first_app.zip', body=pkg1)
+        m.get(murano_repo_url + '/apps/second_app.1.0.zip',
+              body=pkg2)
+        s = io.StringIO()
+        bundle_contents = {'Packages': [
+            {'Name': 'first_app'},
+            {'Name': 'second_app', 'Version': '1.0'}
+        ]}
+        json.dump(bundle_contents, s)
+        s = io.BytesIO(s.getvalue().encode('ascii'))
+
+        m.get(murano_repo_url + '/bundles/test_bundle.bundle',
+              body=s)
+
+        arglist = ["test_bundle", '--murano-repo-url', murano_repo_url]
+        parsed_args = self.check_parser(self.cmd, arglist, [])
+        self.cmd.take_action(parsed_args)
+
+        self.package_mock.create.assert_has_calls(
+            [
+                mock.call({'is_public': False}, {'first_app': mock.ANY}),
+                mock.call({'is_public': False}, {'second_app': mock.ANY}),
+            ], any_order=True,
+        )
+
+    @requests_mock.mock()
+    def test_import_bundle_wrong_url(self, m):
+        url = 'http://127.0.0.2/test_bundle.bundle'
+        m.get(url, status_code=404)
+
+        arglist = [url]
+        parsed_args = self.check_parser(self.cmd, arglist, [])
+        self.cmd.take_action(parsed_args)
+
+        self.assertFalse(self.package_mock.packages.create.called)
+
+    @requests_mock.mock()
+    def test_import_bundle_no_bundle(self, m):
+        url = 'http://127.0.0.1/bundles/test_bundle.bundle'
+        m.get(url, status_code=404)
+
+        arglist = ["test_bundle"]
+        parsed_args = self.check_parser(self.cmd, arglist, [])
+        self.cmd.take_action(parsed_args)
+
+        self.assertFalse(self.package_mock.packages.create.called)
+
+    @requests_mock.mock()
+    def test_import_bundle_by_url(self, m):
+        """Asserts bundle import calls packages create once for each pkg."""
+        pkg1 = make_pkg({'FullName': 'first_app'})
+        pkg2 = make_pkg({'FullName': 'second_app'})
+
+        murano_repo_url = 'http://127.0.0.1'
+        m.get(murano_repo_url + '/apps/first_app.zip', body=pkg1)
+        m.get(murano_repo_url + '/apps/second_app.1.0.zip',
+              body=pkg2)
+        s = io.StringIO()
+        bundle_contents = {'Packages': [
+            {'Name': 'first_app'},
+            {'Name': 'second_app', 'Version': '1.0'}
+        ]}
+        json.dump(bundle_contents, s)
+        s = io.BytesIO(s.getvalue().encode('ascii'))
+
+        url = 'http://127.0.0.2/test_bundle.bundle'
+        m.get(url, body=s)
+
+        arglist = [url, '--murano-repo-url', murano_repo_url]
+        parsed_args = self.check_parser(self.cmd, arglist, [])
+        self.cmd.take_action(parsed_args)
+
+        self.package_mock.create.assert_has_calls(
+            [
+                mock.call({'is_public': False}, {'first_app': mock.ANY}),
+                mock.call({'is_public': False}, {'second_app': mock.ANY}),
+            ], any_order=True,
+        )
+
+    @requests_mock.mock()
+    def test_import_local_bundle(self, m):
+        """Asserts local bundles are first searched locally."""
+        tmp_dir = tempfile.mkdtemp()
+        bundle_file = os.path.join(tmp_dir, 'bundle.bundle')
+        with open(os.path.join(tmp_dir, 'bundle.bundle'), 'w') as f:
+
+            bundle_contents = {'Packages': [
+                {'Name': 'first_app'},
+                {'Name': 'second_app', 'Version': '1.0'}
+            ]}
+            json.dump(bundle_contents, f)
+
+        pkg1 = make_pkg({'FullName': 'first_app',
+                         'Require': {'third_app': None}})
+        pkg2 = make_pkg({'FullName': 'second_app'})
+        pkg3 = make_pkg({'FullName': 'third_app'})
+        with open(os.path.join(tmp_dir, 'first_app'), 'wb') as f:
+            f.write(pkg1.read())
+        with open(os.path.join(tmp_dir, 'third_app'), 'wb') as f:
+            f.write(pkg3.read())
+
+        murano_repo_url = "http://127.0.0.1"
+        m.get(murano_repo_url + '/apps/first_app.zip',
+              status_code=404)
+        m.get(murano_repo_url + '/apps/second_app.1.0.zip',
+              body=pkg2)
+        m.get(murano_repo_url + '/apps/third_app.zip',
+              status_code=404)
+
+        arglist = [bundle_file, '--murano-repo-url', murano_repo_url]
+        parsed_args = self.check_parser(self.cmd, arglist, [])
+        self.cmd.take_action(parsed_args)
+
+        self.package_mock.create.assert_has_calls(
+            [
+                mock.call({'is_public': False}, {'first_app': mock.ANY}),
+                mock.call({'is_public': False}, {'second_app': mock.ANY}),
+                mock.call({'is_public': False}, {'third_app': mock.ANY}),
+            ], any_order=True,
+        )
+        shutil.rmtree(tmp_dir)
+
+
+class TestShowPackage(TestPackage):
+    def setUp(self):
+        super(TestShowPackage, self).setUp()
+
+        # Command to test
+        self.cmd = osc_pkg.ShowPackage(self.app, None)
+
+    def test_package_show(self):
+        arglist = ['fake']
+        verifylist = [('id', 'fake')]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        # Check that columns are correct
+        expected_columns = ('categories', 'class_definitions', 'description',
+                            'enabled', 'fully_qualified_name', 'id',
+                            'is_public', 'name', 'owner_id', 'tags', 'type')
+        self.assertEqual(expected_columns, columns)
+
+        self.package_mock.get.assert_called_with('fake')
+
+
+class TestUpdatePackage(TestPackage):
+    def setUp(self):
+        super(TestUpdatePackage, self).setUp()
+
+        self.package_mock.update.return_value = \
+            (mock.MagicMock(), mock.MagicMock())
+
+        # Command to test
+        self.cmd = osc_pkg.UpdatePackage(self.app, None)
+
+    def test_package_update(self):
+        arglist = ['123', '--is-public', 'true']
+        verifylist = [('id', '123'), ('is_public', True)]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+
+        self.package_mock.update.assert_called_with('123', {'is_public': True})
+
+        arglist = ['123', '--enabled', 'true']
+        verifylist = [('id', '123'), ('enabled', True)]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+
+        self.package_mock.update.assert_called_with('123', {'enabled': True})
+
+        arglist = ['123', '--name', 'foo', '--description', 'bar']
+        verifylist = [('id', '123'), ('name', 'foo'), ('description', 'bar')]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+
+        self.package_mock.update.assert_called_with(
+            '123', {'name': 'foo', 'description': 'bar'})
+
+        arglist = ['123', '--tags', 'foo']
+        verifylist = [('id', '123'), ('tags', ['foo'])]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+
+        self.package_mock.update.assert_called_with(
+            '123', {'tags': ['foo']})
+
+
+class TestDownloadPackage(TestPackage):
+    def setUp(self):
+        super(TestDownloadPackage, self).setUp()
+
+        self.package_mock.download.return_value = \
+            b'This is a fake package buffer'
+
+        # Command to test
+        self.cmd = osc_pkg.DownloadPackage(self.app, None)
+
+    def test_package_download(self):
+        arglist = ['1234', '/tmp/foo.zip']
+        verifylist = [('id', '1234'), ('filename', '/tmp/foo.zip')]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.package_mock.download.assert_called_with('1234')
